@@ -301,6 +301,9 @@ photos_collection_icon_watcher_start (PhotosCollectionIconWatcher *self)
 
   photos_collection_icon_watcher_clear (self);
 
+  if (G_UNLIKELY (priv->queue == NULL))
+    return;
+
   id = photos_base_item_get_id (priv->collection);
   query = photos_query_builder_collection_icon_query (id);
   photos_tracker_queue_select (priv->queue,
@@ -388,7 +391,7 @@ photos_collection_icon_watcher_init (PhotosCollectionIconWatcher *self)
 
   priv->item_connections = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_object_unref);
   priv->item_mngr = photos_item_manager_dup_singleton ();
-  priv->queue = photos_tracker_queue_dup_singleton ();
+  priv->queue = photos_tracker_queue_dup_singleton (NULL, NULL);
 }
 
 
