@@ -256,7 +256,9 @@ photos_embed_hide_no_results_page (PhotosEmbed *self)
 {
   PhotosEmbedPrivate *priv = self->priv;
 
-  g_signal_handlers_disconnect_by_func (priv->monitor, photos_embed_changes_pending, self);
+  if (G_LIKELY (priv->monitor != NULL))
+    g_signal_handlers_disconnect_by_func (priv->monitor, photos_embed_changes_pending, self);
+
   photos_embed_restore_last_page (self);
 }
 
@@ -280,11 +282,12 @@ photos_embed_count_changed (PhotosEmbed *self, gint count)
 
   if (count == 0)
     {
-      g_signal_connect_object (priv->monitor,
-                               "changes-pending",
-                               G_CALLBACK (photos_embed_changes_pending),
-                               self,
-                               G_CONNECT_SWAPPED);
+      if (G_LIKELY (priv->monitor != NULL))
+        g_signal_connect_object (priv->monitor,
+                                 "changes-pending",
+                                 G_CALLBACK (photos_embed_changes_pending),
+                                 self,
+                                 G_CONNECT_SWAPPED);
       gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "no-results");
     }
   else
@@ -386,9 +389,8 @@ photos_embed_query_error (PhotosEmbed *self, const gchar *primary, const gchar *
 
 
 static void
-photos_embed_query_status_changed (PhotosTrackerController *trk_cntrlr, gboolean querying, gpointer user_data)
+photos_embed_query_status_changed (PhotosEmbed *self, gboolean querying)
 {
-  PhotosEmbed *self = PHOTOS_EMBED (user_data);
   PhotosEmbedPrivate *priv = self->priv;
 
   if (querying)
@@ -498,12 +500,12 @@ photos_embed_init (PhotosEmbed *self)
 
   priv->indexing_ntfctn = g_object_ref_sink (photos_indexing_notification_new ());
 
+  priv->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW);
+  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", _("Recent"));
+
   priv->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS);
   gtk_stack_add_titled (GTK_STACK (priv->stack), priv->collections, "collections", _("Albums"));
 
-  priv->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW);
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", _("Photos"));
-
   priv->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES);
   gtk_stack_add_titled (GTK_STACK (priv->stack), priv->favorites, "favorites", _("Favorites"));
 
@@ -538,10 +540,10 @@ photos_embed_init (PhotosEmbed *self)
 
   priv->trk_ovrvw_cntrlr = photos_tracker_overview_controller_dup_singleton ();
   g_signal_connect_swapped (priv->trk_ovrvw_cntrlr, "query-error", G_CALLBACK (photos_embed_query_error), self);
-  g_signal_connect (priv->trk_ovrvw_cntrlr,
-                    "query-status-changed",
-                    G_CALLBACK (photos_embed_query_status_changed),
-                    self);
+  g_signal_connect_swapped (priv->trk_ovrvw_cntrlr,
+                            "query-status-changed",
+                            G_CALLBACK (photos_embed_query_status_changed),
+                            self);
 
   priv->offset_cntrlr = photos_offset_overview_controller_dup_singleton ();
   g_signal_connect_swapped (priv->offset_cntrlr, "count-changed", G_CALLBACK (photos_embed_count_changed), self);
@@ -550,9 +552,9 @@ photos_embed_init (PhotosEmbed *self)
   g_signal_connect (priv->item_mngr, "active-changed", G_CALLBACK (photos_embed_active_changed), self);
 
   querying = photos_tracker_controller_get_query_status (priv->trk_ovrvw_cntrlr);
-  photos_embed_query_status_changed (priv->trk_ovrvw_cntrlr, querying, self);
+  photos_embed_query_status_changed (self, querying);
 
-  priv->monitor = photos_tracker_change_monitor_dup_singleton ();
+  priv->monitor = photos_tracker_change_monitor_dup_singleton (NULL, NULL);
 
   gtk_widget_show (GTK_WIDGET (self));
 }
