@@ -179,7 +179,7 @@ photos_fetch_collections_job_init (PhotosFetchCollectionsJob *self)
   self->priv = photos_fetch_collections_job_get_instance_private (self);
   priv = self->priv;
 
-  priv->queue = photos_tracker_queue_dup_singleton ();
+  priv->queue = photos_tracker_queue_dup_singleton (NULL, NULL);
 }
 
 
@@ -217,6 +217,13 @@ photos_fetch_collections_job_run (PhotosFetchCollectionsJob *self,
   PhotosFetchCollectionsJobPrivate *priv = self->priv;
   PhotosQuery *query;
 
+  if (G_UNLIKELY (priv->queue == NULL))
+    {
+      if (callback != NULL)
+        (*callback) (NULL, user_data);
+      return;
+    }
+
   priv->callback = callback;
   priv->user_data = user_data;
 
