@@ -169,7 +169,7 @@ photos_single_item_job_init (PhotosSingleItemJob *self)
   self->priv = photos_single_item_job_get_instance_private (self);
   priv = self->priv;
 
-  priv->queue = photos_tracker_queue_dup_singleton ();
+  priv->queue = photos_tracker_queue_dup_singleton (NULL, NULL);
 }
 
 
@@ -208,6 +208,13 @@ photos_single_item_job_run (PhotosSingleItemJob *self,
   PhotosSingleItemJobPrivate *priv = self->priv;
   PhotosQuery *query;
 
+  if (G_UNLIKELY (priv->queue == NULL))
+    {
+      if (callback != NULL)
+        (*callback) (NULL, user_data);
+      return;
+    }
+
   priv->callback = callback;
   priv->user_data = user_data;
 
