@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,10 +37,13 @@
 
 struct _PhotosTrackerChangeMonitorPrivate
 {
-  GHashTable *pending;
+  GHashTable *pending_changes;
+  GHashTable *unresolved_ids;
+  GQueue *pending_events;
   PhotosTrackerQueue *queue;
   TrackerResources *resource_service;
   guint outstanding_ops;
+  guint pending_events_id;
 };
 
 enum
@@ -51,8 +54,19 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void photos_tracker_change_monitor_initable_iface_init (GInitableIface *iface);
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosTrackerChangeMonitor, photos_tracker_change_monitor, G_TYPE_OBJECT);
+
+G_DEFINE_TYPE_WITH_CODE (PhotosTrackerChangeMonitor, photos_tracker_change_monitor, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (PhotosTrackerChangeMonitor)
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE, photos_tracker_change_monitor_initable_iface_init));
+
+
+enum
+{
+  CHANGE_MONITOR_TIMEOUT = 500, /* ms */
+  CHANGE_MONITOR_MAX_ITEMS = 500
+};
 
 
 typedef struct _PhotosTrackerChangeMonitorQueryData PhotosTrackerChangeMonitorQueryData;
@@ -61,7 +75,8 @@ typedef struct _TrackerResourcesEvent TrackerResourcesEvent;
 struct _PhotosTrackerChangeMonitorQueryData
 {
   PhotosTrackerChangeMonitor *self;
-  gboolean is_delete;
+  GHashTable *id_table;
+  GQueue *events;
 };
 
 struct _TrackerResourcesEvent
@@ -73,74 +88,83 @@ struct _TrackerResourcesEvent
 } __attribute__ ((packed));
 
 
-static PhotosTrackerChangeMonitorQueryData *
-photos_tracker_change_monitor_query_data_copy (PhotosTrackerChangeMonitorQueryData *data)
-{
-  PhotosTrackerChangeMonitorQueryData *copy;
-
-  copy = g_slice_new0 (PhotosTrackerChangeMonitorQueryData);
-  copy->self = g_object_ref (data->self);
-  copy->is_delete = data->is_delete;
-
-  return copy;
-}
-
-
 static void
 photos_tracker_change_monitor_query_data_free (PhotosTrackerChangeMonitorQueryData *data)
 {
   g_clear_object (&data->self);
+
+  if (data->id_table != NULL)
+    g_hash_table_unref (data->id_table);
+
+  if (data->events != NULL)
+    g_queue_free (data->events);
+
   g_slice_free (PhotosTrackerChangeMonitorQueryData, data);
 }
 
 
 static PhotosTrackerChangeMonitorQueryData *
-photos_tracker_change_monitor_query_data_new (PhotosTrackerChangeMonitor *self, gboolean is_delete)
+photos_tracker_change_monitor_query_data_new (PhotosTrackerChangeMonitor *self,
+                                              GHashTable *id_table,
+                                              GQueue *events)
 {
   PhotosTrackerChangeMonitorQueryData *data;
 
   data = g_slice_new0 (PhotosTrackerChangeMonitorQueryData);
   data->self = g_object_ref (self);
-  data->is_delete = is_delete;
+  data->id_table = id_table;
+  data->events = events;
 
   return data;
 }
 
 
 static void
-photos_tracker_change_monitor_add_event (PhotosTrackerChangeMonitor *self,
-                                         const gchar *subject,
-                                         const gchar *predicate,
-                                         gboolean is_delete)
+photos_tracker_change_monitor_add_event (PhotosTrackerChangeMonitor *self, PhotosTrackerChangeEvent *change_event)
 {
   PhotosTrackerChangeMonitorPrivate *priv = self->priv;
-  PhotosTrackerChangeEvent *event;
-  PhotosTrackerChangeEvent *old_event;
+  PhotosTrackerChangeEvent *old_change_event;
+  const gchar *urn;
 
-  event = photos_tracker_change_event_new (subject, predicate, is_delete);
-  old_event = (PhotosTrackerChangeEvent *) g_hash_table_lookup (priv->pending, subject);
+  urn = photos_tracker_change_event_get_urn (change_event);
+  old_change_event = (PhotosTrackerChangeEvent *) g_hash_table_lookup (priv->pending_changes, urn);
 
-  if (old_event != NULL)
+  if (old_change_event != NULL)
     {
-      photos_tracker_change_event_merge (old_event, event);
-      photos_tracker_change_event_free (event);
+      photos_tracker_change_event_merge (old_change_event, change_event);
+      photos_tracker_change_event_free (change_event);
     }
   else
-    g_hash_table_insert (priv->pending, (gpointer) g_strdup (subject), (gpointer) event);
+    g_hash_table_insert (priv->pending_changes, g_strdup (urn), change_event);
 }
 
 
 static void
-photos_tracker_change_monitor_update_collector (PhotosTrackerChangeMonitor *self)
+photos_tracker_change_monitor_send_events (PhotosTrackerChangeMonitor *self, GHashTable *id_table, GQueue *events)
 {
   PhotosTrackerChangeMonitorPrivate *priv = self->priv;
+  GList *l;
 
-  priv->outstanding_ops--;
-  if (priv->outstanding_ops != 0)
-    return;
+  for (l = events->head; l != NULL; l = l->next)
+    {
+      PhotosTrackerChangeEvent *change_event = (PhotosTrackerChangeEvent *) l->data;
+      const gchar *predicate;
+      const gchar *urn;
+      gint32 predicate_id;
+      gint32 urn_id;
 
-  g_signal_emit (self, signals[CHANGES_PENDING], 0, priv->pending);
-  g_hash_table_remove_all (priv->pending);
+      predicate_id = photos_tracker_change_event_get_predicate_id (change_event);
+      urn_id = photos_tracker_change_event_get_urn_id (change_event);
+
+      predicate = (gchar *) g_hash_table_lookup (id_table, GINT_TO_POINTER (predicate_id));
+      urn = (gchar *) g_hash_table_lookup (id_table, GINT_TO_POINTER (urn_id));
+
+      photos_tracker_change_event_set_resolved_values (change_event, urn, predicate);
+      photos_tracker_change_monitor_add_event (self, change_event); /* steals change_event */
+    }
+
+  g_signal_emit (self, signals[CHANGES_PENDING], 0, priv->pending_changes);
+  g_hash_table_remove_all (priv->pending_changes);
 }
 
 
@@ -148,22 +172,37 @@ static void
 photos_tracker_change_monitor_cursor_next (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   PhotosTrackerChangeMonitorQueryData *data = (PhotosTrackerChangeMonitorQueryData *) user_data;
+  PhotosTrackerChangeMonitor *self = data->self;
   TrackerSparqlCursor *cursor = TRACKER_SPARQL_CURSOR (source_object);
+  GError *error;
+  GHashTableIter iter;
   gboolean valid;
 
-  valid = tracker_sparql_cursor_next_finish (cursor, res, NULL);
-  if (valid)
+  error = NULL;
+  valid = tracker_sparql_cursor_next_finish (cursor, res, &error);
+  if (error != NULL)
     {
-      const gchar *predicate;
-      const gchar *subject;
-
-      subject = tracker_sparql_cursor_get_string (cursor, 0, NULL);
-      predicate = tracker_sparql_cursor_get_string (cursor, 1, NULL);
-      if (subject != NULL && predicate != NULL)
-        photos_tracker_change_monitor_add_event (data->self, subject, predicate, data->is_delete);
+      g_warning ("Unable to resolve item URNs for graph changes: %s", error->message);
+      g_error_free (error);
     }
 
-  photos_tracker_change_monitor_update_collector (data->self);
+  if (valid)
+    {
+      guint idx;
+
+      idx = 0;
+      g_hash_table_iter_init (&iter, data->id_table);
+      while (g_hash_table_iter_next (&iter, NULL, NULL))
+        {
+          const gchar *str;
+
+          str = tracker_sparql_cursor_get_string (cursor, idx, NULL);
+          g_hash_table_iter_replace (&iter, g_strdup (str));
+          idx++;
+        }
+
+      photos_tracker_change_monitor_send_events (self, data->id_table, data->events);
+    }
 
   tracker_sparql_cursor_close (cursor);
   photos_tracker_change_monitor_query_data_free (data);
@@ -182,39 +221,82 @@ photos_tracker_change_monitor_query_executed (GObject *source_object, GAsyncResu
   cursor = tracker_sparql_connection_query_finish (connection, res, &error);
   if (error != NULL)
     {
+      g_warning ("Unable to resolve item URNs for graph changes: %s", error->message);
       g_error_free (error);
+      photos_tracker_change_monitor_query_data_free (data);
       return;
     }
 
-  tracker_sparql_cursor_next_async (cursor,
-                                    NULL,
-                                    photos_tracker_change_monitor_cursor_next,
-                                    photos_tracker_change_monitor_query_data_copy (data));
+  tracker_sparql_cursor_next_async (cursor, NULL, photos_tracker_change_monitor_cursor_next, data);
   g_object_unref (cursor);
 }
 
 
-static void
-photos_tracker_change_monitor_update_iterator (PhotosTrackerChangeMonitor *self,
-                                               const TrackerResourcesEvent *event,
-                                               gboolean is_delete)
+static gboolean
+photos_tracker_change_monitor_process_events (PhotosTrackerChangeMonitor *self)
 {
+  PhotosTrackerChangeMonitorPrivate *priv = self->priv;
+  GHashTable *id_table;
+  GHashTableIter iter;
+  GQueue *events;
+  GString *sparql;
   PhotosTrackerChangeMonitorQueryData *data;
-  gchar *sparql;
+  gpointer id;
 
-  sparql = g_strdup_printf ("SELECT tracker:uri(%" G_GINT32_FORMAT ") tracker:uri(%" G_GINT32_FORMAT ") {}",
-                            event->second,
-                            event->third);
+  events = priv->pending_events;
+  priv->pending_events = g_queue_new ();
 
-  data = photos_tracker_change_monitor_query_data_new (self, is_delete);
+  id_table = priv->unresolved_ids;
+  priv->unresolved_ids = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
 
-  photos_tracker_queue_select (self->priv->queue,
-                               sparql,
+  priv->pending_events_id = 0;
+
+  sparql = g_string_new ("SELECT");
+
+  g_hash_table_iter_init (&iter, id_table);
+  while (g_hash_table_iter_next (&iter, &id, NULL))
+    g_string_append_printf (sparql, " tracker:uri(%d)", GPOINTER_TO_INT (id));
+
+  g_string_append (sparql, " {}");
+
+  data = photos_tracker_change_monitor_query_data_new (self, id_table, events);
+  photos_tracker_queue_select (priv->queue,
+                               sparql->str,
                                NULL,
                                photos_tracker_change_monitor_query_executed,
                                data,
-                               (GDestroyNotify) photos_tracker_change_monitor_query_data_free);
-  g_free (sparql);
+                               NULL);
+
+  g_string_free (sparql, TRUE);
+  return G_SOURCE_REMOVE;
+}
+
+
+static void
+photos_tracker_change_monitor_add_pending_event (PhotosTrackerChangeMonitor *self,
+                                                 const TrackerResourcesEvent *event,
+                                                 gboolean is_delete)
+{
+  PhotosTrackerChangeMonitorPrivate *priv = self->priv;
+  PhotosTrackerChangeEvent *change_event;
+
+  if (priv->pending_events_id != 0)
+    g_source_remove (priv->pending_events_id);
+
+  g_hash_table_insert (priv->unresolved_ids, GINT_TO_POINTER (event->second), NULL);
+  g_hash_table_insert (priv->unresolved_ids, GINT_TO_POINTER (event->third), NULL);
+
+  change_event = photos_tracker_change_event_new (event->second, event->third, is_delete);
+  g_queue_push_tail (priv->pending_events, change_event);
+
+  if (priv->pending_events->length >= CHANGE_MONITOR_MAX_ITEMS)
+    photos_tracker_change_monitor_process_events (self);
+  else
+    priv->pending_events_id = g_timeout_add_full (G_PRIORITY_DEFAULT,
+                                                  CHANGE_MONITOR_TIMEOUT,
+                                                  (GSourceFunc) photos_tracker_change_monitor_process_events,
+                                                  g_object_ref (self),
+                                                  g_object_unref);
 }
 
 
@@ -226,7 +308,6 @@ photos_tracker_change_monitor_graph_updated (TrackerResources *resource_service,
                                              gpointer user_data)
 {
   PhotosTrackerChangeMonitor *self = PHOTOS_TRACKER_CHANGE_MONITOR (user_data);
-  PhotosTrackerChangeMonitorPrivate *priv = self->priv;
   const TrackerResourcesEvent *events;
   gsize i;
   gsize n_elements;
@@ -235,19 +316,13 @@ photos_tracker_change_monitor_graph_updated (TrackerResources *resource_service,
                                                                       &n_elements,
                                                                       sizeof (TrackerResourcesEvent));
   for (i = 0; i < n_elements; i++)
-    {
-      priv->outstanding_ops++;
-      photos_tracker_change_monitor_update_iterator (self, &events[i], TRUE);
-    }
+    photos_tracker_change_monitor_add_pending_event (self, &events[i], TRUE);
 
   events = (const TrackerResourcesEvent *) g_variant_get_fixed_array (insert_events,
                                                                       &n_elements,
                                                                       sizeof (TrackerResourcesEvent));
   for (i = 0; i < n_elements; i++)
-    {
-      priv->outstanding_ops++;
-      photos_tracker_change_monitor_update_iterator (self, &events[i], FALSE);
-    }
+    photos_tracker_change_monitor_add_pending_event (self, &events[i], FALSE);
 }
 
 
@@ -277,12 +352,6 @@ photos_tracker_change_monitor_dispose (GObject *object)
   PhotosTrackerChangeMonitor *self = PHOTOS_TRACKER_CHANGE_MONITOR (object);
   PhotosTrackerChangeMonitorPrivate *priv = self->priv;
 
-  if (priv->pending != NULL)
-    {
-      g_hash_table_unref (priv->pending);
-      priv->pending = NULL;
-    }
-
   g_clear_object (&priv->queue);
   g_clear_object (&priv->resource_service);
 
@@ -290,6 +359,21 @@ photos_tracker_change_monitor_dispose (GObject *object)
 }
 
 
+static void
+photos_tracker_change_monitor_finalize (GObject *object)
+{
+  PhotosTrackerChangeMonitor *self = PHOTOS_TRACKER_CHANGE_MONITOR (object);
+  PhotosTrackerChangeMonitorPrivate *priv = self->priv;
+
+  g_hash_table_unref (priv->pending_changes);
+  g_hash_table_unref (priv->unresolved_ids);
+
+  g_queue_free_full (priv->pending_events, (GDestroyNotify) photos_tracker_change_event_free);
+
+  G_OBJECT_CLASS (photos_tracker_change_monitor_parent_class)->finalize (object);
+}
+
+
 static void
 photos_tracker_change_monitor_init (PhotosTrackerChangeMonitor *self)
 {
@@ -298,22 +382,14 @@ photos_tracker_change_monitor_init (PhotosTrackerChangeMonitor *self)
   self->priv = photos_tracker_change_monitor_get_instance_private (self);
   priv = self->priv;
 
-  priv->pending = g_hash_table_new_full (g_str_hash,
-                                         g_str_equal,
-                                         g_free,
-                                         (GDestroyNotify) photos_tracker_change_event_free);
+  priv->pending_changes = g_hash_table_new_full (g_str_hash,
+                                                 g_str_equal,
+                                                 g_free,
+                                                 (GDestroyNotify) photos_tracker_change_event_free);
 
-  priv->queue = photos_tracker_queue_dup_singleton ();
-  priv->resource_service = tracker_resources_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
-                                                                     G_DBUS_PROXY_FLAGS_NONE,
-                                                                     "org.freedesktop.Tracker1",
-                                                                     "/org/freedesktop/Tracker1/Resources",
-                                                                     NULL,
-                                                                     NULL);
-  g_signal_connect (priv->resource_service,
-                    "graph-updated",
-                    G_CALLBACK (photos_tracker_change_monitor_graph_updated),
-                    self);
+  priv->unresolved_ids = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
+
+  priv->pending_events = g_queue_new ();
 }
 
 
@@ -324,6 +400,7 @@ photos_tracker_change_monitor_class_init (PhotosTrackerChangeMonitorClass *class
 
   object_class->constructor = photos_tracker_change_monitor_constructor;
   object_class->dispose = photos_tracker_change_monitor_dispose;
+  object_class->finalize = photos_tracker_change_monitor_finalize;
 
   signals[CHANGES_PENDING] = g_signal_new ("changes-pending",
                                            G_TYPE_FROM_CLASS (class),
@@ -338,8 +415,54 @@ photos_tracker_change_monitor_class_init (PhotosTrackerChangeMonitorClass *class
 }
 
 
-PhotosTrackerChangeMonitor *
-photos_tracker_change_monitor_dup_singleton (void)
+static gboolean
+photos_tracker_change_monitor_initable_init (GInitable *initable, GCancellable *cancellable, GError **error)
 {
-  return g_object_new (PHOTOS_TYPE_TRACKER_CHANGE_MONITOR, NULL);
+  PhotosTrackerChangeMonitor *self = PHOTOS_TRACKER_CHANGE_MONITOR (initable);
+  PhotosTrackerChangeMonitorPrivate *priv = self->priv;
+  gboolean ret_val = TRUE;
+
+  if (G_LIKELY (priv->queue != NULL && priv->resource_service != NULL))
+    goto out;
+
+  priv->queue = photos_tracker_queue_dup_singleton (cancellable, error);
+  if (G_UNLIKELY (priv->queue == NULL))
+    {
+      ret_val = FALSE;
+      goto out;
+    }
+
+  priv->resource_service = tracker_resources_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
+                                                                     G_DBUS_PROXY_FLAGS_NONE,
+                                                                     "org.freedesktop.Tracker1",
+                                                                     "/org/freedesktop/Tracker1/Resources",
+                                                                     cancellable,
+                                                                     error);
+  if (G_UNLIKELY (priv->resource_service == NULL))
+    {
+      ret_val = FALSE;
+      goto out;
+    }
+
+  g_signal_connect (priv->resource_service,
+                    "graph-updated",
+                    G_CALLBACK (photos_tracker_change_monitor_graph_updated),
+                    self);
+
+ out:
+  return ret_val;
+}
+
+
+static void
+photos_tracker_change_monitor_initable_iface_init (GInitableIface *iface)
+{
+  iface->init = photos_tracker_change_monitor_initable_init;
+}
+
+
+PhotosTrackerChangeMonitor *
+photos_tracker_change_monitor_dup_singleton (GCancellable *cancellable, GError **error)
+{
+  return g_initable_new (PHOTOS_TYPE_TRACKER_CHANGE_MONITOR, cancellable, error, NULL);
 }
